@@ -18,7 +18,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'BINDIR': '/clangarm64/bin',
  'BINLIBDEST': '/clangarm64/lib/python3.11',
  'BLDLIBRARY': '-L. -lpython3.11',
- 'BLDSHARED': 'clang -shared -Wl,--enable-auto-image-base -pipe -pipe',
+ 'BLDSHARED': 'clang -shared -Wl,--enable-auto-image-base',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '.exe',
  'BUILDPYTHON': 'python.exe',
@@ -42,8 +42,8 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                             '-fvisibility=hidden -D_WIN32_WINNT=0x0602 '
                             '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                             '-DMS_DLL_ID=\'"3.11-arm64"\'',
- 'CONFIGURE_CPPFLAGS': '-I../Python-3.11.8/PC -D__USE_MINGW_ANSI_STDIO=1 -I.',
- 'CONFIGURE_LDFLAGS': '-pipe',
+ 'CONFIGURE_CPPFLAGS': '-I../Python-3.11.9/PC -D__USE_MINGW_ANSI_STDIO=1 -I.',
+ 'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--prefix=/clangarm64' '--host=aarch64-w64-mingw32' "
@@ -56,7 +56,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                 "'host_alias=aarch64-w64-mingw32' "
                 "'PKG_CONFIG_PATH=/clangarm64/lib/pkgconfig:/clangarm64/share/pkgconfig' "
                 "'CC=clang' 'CFLAGS=-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 "
-                "-fstack-protector-strong -O3' 'LDFLAGS=-pipe' "
+                "-fstack-protector-strong -O3' 'LDFLAGS=' "
                 "'CPPFLAGS=-D__USE_MINGW_ANSI_STDIO=1'",
  'CONFINCLUDEDIR': '/clangarm64/include',
  'CONFINCLUDEPY': '/clangarm64/include/python3.11',
@@ -67,16 +67,16 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
- 'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Python-3.11.8/Include '
-             '-I../Python-3.11.8/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
+ 'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Python-3.11.9/Include '
+             '-I../Python-3.11.9/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
              '-D__USE_MINGW_ANSI_STDIO=1',
  'CXX': 'clang++',
  'DECIMAL_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1',
  'DECIMAL_LDFLAGS': '-lmpdec',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
- 'DEEPFREEZE_DEPS': '../Python-3.11.8/Tools/scripts/deepfreeze.py '
+ 'DEEPFREEZE_DEPS': '../Python-3.11.9/Tools/scripts/deepfreeze.py '
                     '_bootstrap_python '
-                    '../Python-3.11.8/Programs/_freeze_module.py \\',
+                    '../Python-3.11.9/Programs/_freeze_module.py \\',
  'DEEPFREEZE_OBJS': 'Python/deepfreeze/deepfreeze.o',
  'DESTDIR': '',
  'DESTDIRFINAL': '/',
@@ -116,11 +116,11 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FREEZE_MODULE': './_bootstrap_python '
-                  '../Python-3.11.8/Programs/_freeze_module.py',
+                  '../Python-3.11.9/Programs/_freeze_module.py',
  'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
  'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
  'FREEZE_MODULE_DEPS': '_bootstrap_python '
-                       '../Python-3.11.8/Programs/_freeze_module.py',
+                       '../Python-3.11.9/Programs/_freeze_module.py',
  'FROZEN_FILES_IN': '\\',
  'FROZEN_FILES_OUT': '\\',
  'GETPGRP_HAVE_ARG': 0,
@@ -626,10 +626,10 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'clang++ -shared -Wl,--enable-auto-image-base',
- 'LDFLAGS': '-pipe -pipe',
+ 'LDFLAGS': '',
  'LDLIBRARY': 'libpython3.11.dll.a',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'clang -shared -Wl,--enable-auto-image-base -pipe -pipe',
+ 'LDSHARED': 'clang -shared -Wl,--enable-auto-image-base',
  'LDVERSION': '3.11',
  'LIBC': '',
  'LIBDEST': '/clangarm64/lib/python3.11',
@@ -643,9 +643,9 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                     '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                     '-DMS_DLL_ID=\'"3.11-arm64"\' '
                     '-fprofile-instr-use=code.profclangd '
-                    '-I../Python-3.11.8/Include/internal -IObjects -IInclude '
-                    '-IPython -I. -I../Python-3.11.8/Include '
-                    '-I../Python-3.11.8/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
+                    '-I../Python-3.11.9/Include/internal -IObjects -IInclude '
+                    '-IPython -I. -I../Python-3.11.9/Include '
+                    '-I../Python-3.11.9/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
                     '-D__USE_MINGW_ANSI_STDIO=1',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
@@ -661,9 +661,9 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                     '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                     '-DMS_DLL_ID=\'"3.11-arm64"\' '
                     '-fprofile-instr-use=code.profclangd '
-                    '-I../Python-3.11.8/Include/internal -IObjects -IInclude '
-                    '-IPython -I. -I../Python-3.11.8/Include '
-                    '-I../Python-3.11.8/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
+                    '-I../Python-3.11.9/Include/internal -IObjects -IInclude '
+                    '-IPython -I. -I../Python-3.11.9/Include '
+                    '-I../Python-3.11.9/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
                     '-D__USE_MINGW_ANSI_STDIO=1',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
@@ -697,7 +697,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MAINCC': 'clang',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '../Python-3.11.8/Modules/makesetup',
+ 'MAKESETUP': '../Python-3.11.9/Modules/makesetup',
  'MANDIR': '/clangarm64/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'atexit  faulthandler  nt  _signal  _tracemalloc  _codecs  '
@@ -728,7 +728,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE_BINASCII_CFLAGS': '-DUSE_ZLIB_CRC32',
  'MODULE_BINASCII_LDFLAGS': '-lz',
  'MODULE_BINASCII_STATE': 'yes',
- 'MODULE_CMATH_DEPS': '../Python-3.11.8/Modules/_math.h',
+ 'MODULE_CMATH_DEPS': '../Python-3.11.9/Modules/_math.h',
  'MODULE_CMATH_LDFLAGS': '-lm',
  'MODULE_CMATH_STATE': 'yes',
  'MODULE_ERRNO_LDFLAGS': '',
@@ -736,7 +736,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE_FCNTL_STATE': 'missing',
  'MODULE_GRP_STATE': 'missing',
  'MODULE_ITERTOOLS_LDFLAGS': '',
- 'MODULE_MATH_DEPS': '../Python-3.11.8/Modules/_math.h',
+ 'MODULE_MATH_DEPS': '../Python-3.11.9/Modules/_math.h',
  'MODULE_MATH_LDFLAGS': '-lm',
  'MODULE_MATH_STATE': 'yes',
  'MODULE_MMAP_STATE': 'yes',
@@ -757,8 +757,8 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE_TERMIOS_STATE': 'missing',
  'MODULE_TIME_LDFLAGS': '',
  'MODULE_TIME_STATE': 'yes',
- 'MODULE_UNICODEDATA_DEPS': '../Python-3.11.8/Modules/unicodedata_db.h '
-                            '../Python-3.11.8/Modules/unicodename_db.h',
+ 'MODULE_UNICODEDATA_DEPS': '../Python-3.11.9/Modules/unicodedata_db.h '
+                            '../Python-3.11.9/Modules/unicodename_db.h',
  'MODULE_UNICODEDATA_STATE': 'yes',
  'MODULE_WINREG_LDFLAGS': '',
  'MODULE_WINSOUND_LDFLAGS': '-lwinmm',
@@ -773,22 +773,22 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE__ASYNCIO_STATE': 'yes',
  'MODULE__BISECT_STATE': 'yes',
  'MODULE__BLAKE2_CFLAGS': '',
- 'MODULE__BLAKE2_DEPS': '../Python-3.11.8/Modules/_blake2/impl/blake2-config.h '
-                        '../Python-3.11.8/Modules/_blake2/impl/blake2-impl.h '
-                        '../Python-3.11.8/Modules/_blake2/impl/blake2.h '
-                        '../Python-3.11.8/Modules/_blake2/impl/blake2b-load-sse2.h '
-                        '../Python-3.11.8/Modules/_blake2/impl/blake2b-load-sse41.h '
-                        '../Python-3.11.8/Modules/_blake2/impl/blake2b-ref.c '
-                        '../Python-3.11.8/Modules/_blake2/impl/blake2b-round.h '
-                        '../Python-3.11.8/Modules/_blake2/impl/blake2b.c '
-                        '../Python-3.11.8/Modules/_blake2/impl/blake2s-load-sse2.h '
-                        '../Python-3.11.8/Modules/_blake2/impl/blake2s-load-sse41.h '
-                        '../Python-3.11.8/Modules/_blake2/impl/blake2s-load-xop.h '
-                        '../Python-3.11.8/Modules/_blake2/impl/blake2s-ref.c '
-                        '../Python-3.11.8/Modules/_blake2/impl/blake2s-round.h '
-                        '../Python-3.11.8/Modules/_blake2/impl/blake2s.c '
-                        '../Python-3.11.8/Modules/_blake2/blake2module.h '
-                        '../Python-3.11.8/Modules/hashlib.h',
+ 'MODULE__BLAKE2_DEPS': '../Python-3.11.9/Modules/_blake2/impl/blake2-config.h '
+                        '../Python-3.11.9/Modules/_blake2/impl/blake2-impl.h '
+                        '../Python-3.11.9/Modules/_blake2/impl/blake2.h '
+                        '../Python-3.11.9/Modules/_blake2/impl/blake2b-load-sse2.h '
+                        '../Python-3.11.9/Modules/_blake2/impl/blake2b-load-sse41.h '
+                        '../Python-3.11.9/Modules/_blake2/impl/blake2b-ref.c '
+                        '../Python-3.11.9/Modules/_blake2/impl/blake2b-round.h '
+                        '../Python-3.11.9/Modules/_blake2/impl/blake2b.c '
+                        '../Python-3.11.9/Modules/_blake2/impl/blake2s-load-sse2.h '
+                        '../Python-3.11.9/Modules/_blake2/impl/blake2s-load-sse41.h '
+                        '../Python-3.11.9/Modules/_blake2/impl/blake2s-load-xop.h '
+                        '../Python-3.11.9/Modules/_blake2/impl/blake2s-ref.c '
+                        '../Python-3.11.9/Modules/_blake2/impl/blake2s-round.h '
+                        '../Python-3.11.9/Modules/_blake2/impl/blake2s.c '
+                        '../Python-3.11.9/Modules/_blake2/blake2module.h '
+                        '../Python-3.11.9/Modules/hashlib.h',
  'MODULE__BLAKE2_LDFLAGS': '',
  'MODULE__BLAKE2_STATE': 'yes',
  'MODULE__BZ2_CFLAGS': '',
@@ -805,27 +805,27 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE__CONTEXTVARS_STATE': 'yes',
  'MODULE__CRYPT_STATE': 'missing',
  'MODULE__CSV_STATE': 'yes',
- 'MODULE__CTYPES_DEPS': '../Python-3.11.8/Modules/_ctypes/ctypes.h',
+ 'MODULE__CTYPES_DEPS': '../Python-3.11.9/Modules/_ctypes/ctypes.h',
  'MODULE__CTYPES_TEST_LDFLAGS': '-lm',
  'MODULE__CTYPES_TEST_STATE': 'yes',
  'MODULE__DATETIME_LDFLAGS': '-lm',
  'MODULE__DATETIME_STATE': 'yes',
  'MODULE__DECIMAL_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1',
- 'MODULE__DECIMAL_DEPS': '../Python-3.11.8/Modules/_decimal/docstrings.h',
+ 'MODULE__DECIMAL_DEPS': '../Python-3.11.9/Modules/_decimal/docstrings.h',
  'MODULE__DECIMAL_LDFLAGS': '-lmpdec',
  'MODULE__DECIMAL_STATE': 'yes',
  'MODULE__ELEMENTTREE_CFLAGS': '',
- 'MODULE__ELEMENTTREE_DEPS': '../Python-3.11.8/Modules/pyexpat.c',
+ 'MODULE__ELEMENTTREE_DEPS': '../Python-3.11.9/Modules/pyexpat.c',
  'MODULE__ELEMENTTREE_STATE': 'yes',
  'MODULE__FUNCTOOLS_LDFLAGS': '',
  'MODULE__GDBM_STATE': 'missing',
  'MODULE__HASHLIB_CFLAGS': '',
- 'MODULE__HASHLIB_DEPS': '../Python-3.11.8/Modules/hashlib.h',
+ 'MODULE__HASHLIB_DEPS': '../Python-3.11.9/Modules/hashlib.h',
  'MODULE__HASHLIB_LDFLAGS': '-lcrypto',
  'MODULE__HASHLIB_STATE': 'yes',
  'MODULE__HEAPQ_STATE': 'yes',
- 'MODULE__IO_CFLAGS': '-I../Python-3.11.8/Modules/_io',
- 'MODULE__IO_DEPS': '../Python-3.11.8/Modules/_io/_iomodule.h',
+ 'MODULE__IO_CFLAGS': '-I../Python-3.11.9/Modules/_io',
+ 'MODULE__IO_DEPS': '../Python-3.11.9/Modules/_io/_iomodule.h',
  'MODULE__IO_LDFLAGS': '',
  'MODULE__IO_STATE': 'yes',
  'MODULE__JSON_STATE': 'yes',
@@ -834,12 +834,12 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE__LZMA_CFLAGS': '',
  'MODULE__LZMA_LDFLAGS': '-llzma',
  'MODULE__LZMA_STATE': 'yes',
- 'MODULE__MD5_DEPS': '../Python-3.11.8/Modules/hashlib.h',
+ 'MODULE__MD5_DEPS': '../Python-3.11.9/Modules/hashlib.h',
  'MODULE__MD5_STATE': 'yes',
  'MODULE__MSI_LDFLAGS': '-lmsi -lcabinet -lrpcrt4',
  'MODULE__MSI_STATE': 'yes',
  'MODULE__MULTIBYTECODEC_STATE': 'yes',
- 'MODULE__MULTIPROCESSING_CFLAGS': '-I../Python-3.11.8/Modules/_multiprocessing',
+ 'MODULE__MULTIPROCESSING_CFLAGS': '-I../Python-3.11.9/Modules/_multiprocessing',
  'MODULE__MULTIPROCESSING_STATE': 'yes',
  'MODULE__OPCODE_STATE': 'yes',
  'MODULE__OPERATOR_LDFLAGS': '',
@@ -851,42 +851,42 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE__QUEUE_STATE': 'yes',
  'MODULE__RANDOM_STATE': 'yes',
  'MODULE__SCPROXY_STATE': 'n/a',
- 'MODULE__SHA1_DEPS': '../Python-3.11.8/Modules/hashlib.h',
+ 'MODULE__SHA1_DEPS': '../Python-3.11.9/Modules/hashlib.h',
  'MODULE__SHA1_STATE': 'yes',
- 'MODULE__SHA256_DEPS': '../Python-3.11.8/Modules/hashlib.h',
+ 'MODULE__SHA256_DEPS': '../Python-3.11.9/Modules/hashlib.h',
  'MODULE__SHA256_STATE': 'yes',
- 'MODULE__SHA3_DEPS': '../Python-3.11.8/Modules/_sha3/sha3.c '
-                      '../Python-3.11.8/Modules/_sha3/sha3.h '
-                      '../Python-3.11.8/Modules/hashlib.h',
+ 'MODULE__SHA3_DEPS': '../Python-3.11.9/Modules/_sha3/sha3.c '
+                      '../Python-3.11.9/Modules/_sha3/sha3.h '
+                      '../Python-3.11.9/Modules/hashlib.h',
  'MODULE__SHA3_STATE': 'yes',
- 'MODULE__SHA512_DEPS': '../Python-3.11.8/Modules/hashlib.h',
+ 'MODULE__SHA512_DEPS': '../Python-3.11.9/Modules/hashlib.h',
  'MODULE__SHA512_STATE': 'yes',
- 'MODULE__SOCKET_DEPS': '../Python-3.11.8/Modules/socketmodule.h '
-                        '../Python-3.11.8/Modules/addrinfo.h '
-                        '../Python-3.11.8/Modules/getaddrinfo.c '
-                        '../Python-3.11.8/Modules/getnameinfo.c',
+ 'MODULE__SOCKET_DEPS': '../Python-3.11.9/Modules/socketmodule.h '
+                        '../Python-3.11.9/Modules/addrinfo.h '
+                        '../Python-3.11.9/Modules/getaddrinfo.c '
+                        '../Python-3.11.9/Modules/getnameinfo.c',
  'MODULE__SOCKET_LDFLAGS': '',
  'MODULE__SOCKET_STATE': 'yes',
- 'MODULE__SQLITE3_CFLAGS': '-I../Python-3.11.8/Modules/_sqlite',
- 'MODULE__SQLITE3_DEPS': '../Python-3.11.8/Modules/_sqlite/connection.h '
-                         '../Python-3.11.8/Modules/_sqlite/cursor.h '
-                         '../Python-3.11.8/Modules/_sqlite/microprotocols.h '
-                         '../Python-3.11.8/Modules/_sqlite/module.h '
-                         '../Python-3.11.8/Modules/_sqlite/prepare_protocol.h '
-                         '../Python-3.11.8/Modules/_sqlite/row.h '
-                         '../Python-3.11.8/Modules/_sqlite/util.h',
+ 'MODULE__SQLITE3_CFLAGS': '-I../Python-3.11.9/Modules/_sqlite',
+ 'MODULE__SQLITE3_DEPS': '../Python-3.11.9/Modules/_sqlite/connection.h '
+                         '../Python-3.11.9/Modules/_sqlite/cursor.h '
+                         '../Python-3.11.9/Modules/_sqlite/microprotocols.h '
+                         '../Python-3.11.9/Modules/_sqlite/module.h '
+                         '../Python-3.11.9/Modules/_sqlite/prepare_protocol.h '
+                         '../Python-3.11.9/Modules/_sqlite/row.h '
+                         '../Python-3.11.9/Modules/_sqlite/util.h',
  'MODULE__SQLITE3_LDFLAGS': '-lsqlite3',
  'MODULE__SQLITE3_STATE': 'yes',
  'MODULE__SRE_LDFLAGS': '',
  'MODULE__SSL_CFLAGS': '',
- 'MODULE__SSL_DEPS': '../Python-3.11.8/Modules/_ssl.h '
-                     '../Python-3.11.8/Modules/_ssl/cert.c '
-                     '../Python-3.11.8/Modules/_ssl/debughelpers.c '
-                     '../Python-3.11.8/Modules/_ssl/misc.c '
-                     '../Python-3.11.8/Modules/_ssl_data.h '
-                     '../Python-3.11.8/Modules/_ssl_data_111.h '
-                     '../Python-3.11.8/Modules/_ssl_data_300.h '
-                     '../Python-3.11.8/Modules/socketmodule.h',
+ 'MODULE__SSL_DEPS': '../Python-3.11.9/Modules/_ssl.h '
+                     '../Python-3.11.9/Modules/_ssl/cert.c '
+                     '../Python-3.11.9/Modules/_ssl/debughelpers.c '
+                     '../Python-3.11.9/Modules/_ssl/misc.c '
+                     '../Python-3.11.9/Modules/_ssl_data.h '
+                     '../Python-3.11.9/Modules/_ssl_data_111.h '
+                     '../Python-3.11.9/Modules/_ssl_data_300.h '
+                     '../Python-3.11.9/Modules/socketmodule.h',
  'MODULE__SSL_LDFLAGS': '-lssl -lcrypto -lws2_32',
  'MODULE__SSL_STATE': 'yes',
  'MODULE__STATISTICS_LDFLAGS': '-lm',
@@ -895,7 +895,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE__STRUCT_STATE': 'yes',
  'MODULE__SYMTABLE_LDFLAGS': '',
  'MODULE__TESTBUFFER_STATE': 'yes',
- 'MODULE__TESTCAPI_DEPS': '../Python-3.11.8/Modules/testcapi_long.h',
+ 'MODULE__TESTCAPI_DEPS': '../Python-3.11.9/Modules/testcapi_long.h',
  'MODULE__TESTCAPI_STATE': 'yes',
  'MODULE__TESTCLINIC_STATE': 'yes',
  'MODULE__TESTIMPORTMULTIPLE_STATE': 'yes',
@@ -972,9 +972,9 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                              '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                              '-DMS_DLL_ID=\'"3.11-arm64"\' '
                              '-fprofile-instr-use=code.profclangd '
-                             '-I../Python-3.11.8/Include/internal -IObjects '
+                             '-I../Python-3.11.9/Include/internal -IObjects '
                              '-IInclude -IPython -I. '
-                             '-I../Python-3.11.8/Include -I../Python-3.11.8/PC '
+                             '-I../Python-3.11.9/Include -I../Python-3.11.9/PC '
                              '-D__USE_MINGW_ANSI_STDIO=1 -I. '
                              '-D__USE_MINGW_ANSI_STDIO=1 '
                              '-DPy_BUILD_CORE_BUILTIN',
@@ -986,7 +986,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                      '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                      '-DMS_DLL_ID=\'"3.11-arm64"\' '
                      '-fprofile-instr-use=code.profclangd '
-                     '-I../Python-3.11.8/Include/internal',
+                     '-I../Python-3.11.9/Include/internal',
  'PY_COERCE_C_LOCALE': 0,
  'PY_CORE_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -O2 -pipe '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -O3 -O2 '
@@ -996,19 +996,19 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                    '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                    '-DMS_DLL_ID=\'"3.11-arm64"\' '
                    '-fprofile-instr-use=code.profclangd '
-                   '-I../Python-3.11.8/Include/internal -IObjects -IInclude '
-                   '-IPython -I. -I../Python-3.11.8/Include '
-                   '-I../Python-3.11.8/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
+                   '-I../Python-3.11.9/Include/internal -IObjects -IInclude '
+                   '-IPython -I. -I../Python-3.11.9/Include '
+                   '-I../Python-3.11.9/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
                    '-D__USE_MINGW_ANSI_STDIO=1 -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-pipe -pipe',
- 'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Python-3.11.8/Include '
-                '-I../Python-3.11.8/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
+ 'PY_CORE_LDFLAGS': '',
+ 'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Python-3.11.9/Include '
+                '-I../Python-3.11.9/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
                 '-D__USE_MINGW_ANSI_STDIO=1',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-pipe -pipe',
+ 'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '',
- 'PY_LDFLAGS_NOLTO': '-pipe -pipe',
+ 'PY_LDFLAGS_NOLTO': '',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
@@ -1022,9 +1022,9 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                         '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                         '-DMS_DLL_ID=\'"3.11-arm64"\' '
                         '-fprofile-instr-use=code.profclangd '
-                        '-I../Python-3.11.8/Include/internal -IObjects '
-                        '-IInclude -IPython -I. -I../Python-3.11.8/Include '
-                        '-I../Python-3.11.8/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
+                        '-I../Python-3.11.9/Include/internal -IObjects '
+                        '-IInclude -IPython -I. -I../Python-3.11.9/Include '
+                        '-I../Python-3.11.9/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
                         '-D__USE_MINGW_ANSI_STDIO=1',
  'PY_SUPPORT_TIER': 0,
  'Py_DEBUG': 0,
@@ -1034,7 +1034,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'Py_SUNOS_VERSION': 0,
  'Py_TRACE_REFS': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
- 'RCFLAGS': '-DFIELD3=8150 -O COFF',
+ 'RCFLAGS': '-DFIELD3=9150 -O COFF',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
@@ -1071,7 +1071,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
             'Modules/_sre   Modules/_xxtestfuzz   Modules/cjkcodecs   '
             'Modules/expat   Objects   Parser   Programs   Python   '
             'Python/frozen_modules   Python/deepfreeze PC',
- 'SRC_GDB_HOOKS': '../Python-3.11.8/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '../Python-3.11.9/Tools/gdb/libpython.py',
  'STATIC_LIBPYTHON': 1,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -1084,7 +1084,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'TESTPATH': '',
  'TESTPYTHON': './python.exe -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': './python.exe -E ../Python-3.11.8/Tools/scripts/run_tests.py',
+ 'TESTRUNNER': './python.exe -E ../Python-3.11.9/Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
@@ -1095,11 +1095,11 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'TZPATH': '/clangarm64/share/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': '../Python-3.11.8/Tools/scripts/update_file.py',
+ 'UPDATE_FILE': '../Python-3.11.9/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
  'VENVLAUNCHERDIR': '/clangarm64/lib/python3.11/venv/scripts/nt',
  'VERSION': '3.11',
- 'VPATH': '../Python-3.11.8',
+ 'VPATH': '../Python-3.11.9',
  'WASM_ASSETS_DIR': './clangarm64',
  'WASM_STDLIB': './clangarm64/lib/python3.11/os.py',
  'WHEEL_PKG_DIR': '',
@@ -1119,14 +1119,14 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
  'abs_builddir': 'C:/M/B/src/build-CLANGARM64',
  'abs_builddir_b2h': 'C:/M/B/src/build-CLANGARM64',
- 'abs_srcdir': 'C:/M/B/src/Python-3.11.8',
- 'abs_srcdir_b2h': 'C:/M/B/src/Python-3.11.8',
+ 'abs_srcdir': 'C:/M/B/src/Python-3.11.9',
+ 'abs_srcdir_b2h': 'C:/M/B/src/Python-3.11.9',
  'datarootdir': '/clangarm64/share',
  'exec_prefix': '/clangarm64',
  'prefix': 'C:/msys64/clangarm64',
  'prefix_b2h': 'C:/msys64/clangarm64',
- 'srcdir': 'C:/M/B/src/Python-3.11.8',
- 'srcdir_b2h': 'C:/M/B/src/Python-3.11.8'}
+ 'srcdir': 'C:/M/B/src/Python-3.11.9',
+ 'srcdir_b2h': 'C:/M/B/src/Python-3.11.9'}
 
 
 keys_to_replace = [
